@@ -27,10 +27,12 @@ def is_name_valid(app_name):
 #get all arguments passed
 def get_args():
   args = sys.argv
+  print(args)
   args.pop(0)
   return args
 
 def is_args_valid(args):
+  print('test')
     valid_args =  all(arg in valid_args_list for arg in args)
     return valid_args
 
